@@ -571,7 +571,16 @@ class GeoArray(object):
         elif isinstance(given, (tuple, list)):
             # handle requests like geoArr[[1,2],[3,4]  -> not implemented in from_path if array is not in mem
             types = [type(i) for i in given]
+
             if list in types or tuple in types:
+
+                # avoid that the whole cube is read if only data from a single band is requested
+                if not self.is_inmem \
+                   and len(given) == 3 \
+                   and isinstance(given[2], (int, float, np.integer, np.floating)):
+                    band_subset = GeoArray(self.filePath)[:, :, given[2]]
+                    return band_subset[given[:2]]
+
                 self.to_mem()
 
             if len(given) == 3:
